@@ -1,4 +1,5 @@
 #' Parse, retaining comments.
+#'
 #' Works very similarly to parse, but also keeps original formatting and
 #' comments.
 #'
@@ -129,11 +130,11 @@ parse_all.connection <- function(x) {
 
 parse_all.function <- function(x) {
   src <- attr(x, "source")
-  src <- str_replace(src, "^function\\(\\)\\s*\\{", "")
-  src <- str_replace(src, "\\}$", "")
-  parse_all(src)
+  # Remove first, function() {,  and last lines, }
+  n <- length(src)
+  parse_all(src[-c(1, n)])
 }
 
 parse_all.default <- function(x) {
   parse_all(deparse(x))
-}
\ No newline at end of file
+}
